@@ -6,6 +6,8 @@ import pytest
 
 from zwave_js_server.__main__ import main
 
+from .common import update_ws_client_msg_queue
+
 # pylint: disable=unused-argument
 
 
@@ -19,19 +21,7 @@ def client_session_fixture(ws_client):
         yield session
 
 
-@pytest.fixture(name="no_get_log_config_client_session")
-def no_get_log_config_client_session_fixture(no_get_log_config_ws_client):
-    """Mock the aiohttp client session that doesn't call get_log_config."""
-    with patch("aiohttp.ClientSession") as session:
-        session.return_value.__aenter__.return_value.ws_connect.side_effect = AsyncMock(
-            return_value=no_get_log_config_ws_client
-        )
-        yield session
-
-
-def test_server_version(
-    no_get_log_config_client_session, url, no_get_log_config_ws_client, result, capsys
-):
+def test_server_version(client_session, url, ws_client, result, capsys):
     """Test print server version."""
     with patch.object(
         sys, "argv", ["zwave_js_server", url, "--server-version"]
@@ -45,15 +35,16 @@ def test_server_version(
         "Server: test_server_version\n"
         "Home ID: test_home_id\n"
     )
-    assert no_get_log_config_ws_client.receive_json.call_count == 1
-    assert no_get_log_config_ws_client.close.call_count == 1
+    assert ws_client.receive_json.call_count == 1
+    assert ws_client.close.call_count == 1
 
 
 @pytest.mark.parametrize("result", ["test_result"])
 def test_dump_state(
-    no_get_log_config_client_session, url, no_get_log_config_ws_client, result, capsys
+    client_session, url, ws_client, result, version_data, set_api_schema_data, capsys
 ):
     """Test dump state."""
+    update_ws_client_msg_queue(ws_client, (version_data, set_api_schema_data, result))
     with patch.object(
         sys, "argv", ["zwave_js_server", url, "--dump-state"]
     ), pytest.raises(SystemExit) as sys_exit:
@@ -69,8 +60,8 @@ def test_dump_state(
         "test_result\n"
     )
 
-    assert no_get_log_config_ws_client.receive_json.call_count == 3
-    assert no_get_log_config_ws_client.close.call_count == 1
+    assert ws_client.receive_json.call_count == 3
+    assert ws_client.close.call_count == 1
 
 
 def test_connect(client_session, url, ws_client):
